From: Junio C Hamano Date: Fri, 27 Sep 2024 00:44:36 GMT Subject: Re: [PATCH v5 0/8] hash.h: support choosing a separate SHA-1 for non-cryptographic uses Message-ID: In-Reply-To: Elijah Newren writes: > Hi... > >> ... >> - , and generate the resulting "clone" much unsafeer, in only 11.597 seconds >> + , and generate the resulting "clone" much faster, in only 11.597 seconds >> of wall time, 11.37 seconds of user time, and 0.23 seconds of system >> time, for a ~40% speed-up. > > This round looks good to me. Thanks, both.